@@ -1,6 +1,7 @@
 from pyscandl.modules import arg_parser, Pyscandl
 from pyscandl.modules.fetchers import FetcherEnum
 from pyscandl.modules.autodl import Controller
+from pyscandl.modules.excepts import DownedSite
 import xml.etree.ElementTree
 
 
@@ -39,7 +40,6 @@ def main():
 				print(f"manga '{args.name}' not in the list, you may consider adding it to it with manga add")
 			elif infos.get("chapters"):
 				print(f"{args.name}:\n",
-					  f"\trss link: {infos.get('rss')}\n",
 					  f"\tmanga link: {infos.get('link')}\n",
 					  f"\tfetcher: {infos.get('fetcher').upper()}\n",
 					  f"\tnumber of chapters already downloaded: {len(infos.get('chapters'))}\n",
@@ -47,7 +47,6 @@ def main():
 					  f"\tarchived: {infos.get('archived')}")
 			else:
 				print(f"{args.name}:\n",
-					  f"\trss link: {infos.get('rss')}\n",
 					  f"\tmanga link: {infos.get('link')}\n",
 					  f"\tfetcher: {infos.get('fetcher').upper()}\n",
 					  f"\tno chapter downloaded yet\n",
@@ -59,7 +58,7 @@ def main():
 				chaps = [float(chap) if "." in chap else int(chap) for chap in args.chap]
 			else:
 				chaps = []
-			json.add(args.name, args.rss, args.link, args.fetcher, chaps, args.archived)
+			json.add(args.name, args.link, args.fetcher, chaps, args.archived)
 			json.save()
 
 		elif args.manga_subparser == "edit":
@@ -76,7 +75,7 @@ def main():
 			else:
 				archive = None
 
-			json.edit(args.name, args.rss, args.link, args.fetcher, chaps, archive)
+			json.edit(args.name, args.link, args.fetcher, chaps, archive)
 			json.save()
 
 		elif args.manga_subparser == "chaplist":
@@ -119,13 +118,23 @@ def main():
 							tries_left = 0
 						except xml.etree.ElementTree.ParseError:
 							if not args.quiet:
-								print(f"problem with the xml fetching for {name}, retrying...")
+								print(f"problem with the fetching for {name}, retrying...")
 							success = False
 							tries_left -= 1
+						except DownedSite:
+							# the website can't be accessed for the time being so no retrying
+							success = False
+							tries_left = 0
 					if success:
-						autodl.download(name, pdf=args.pdf, keep=args.keep, image=args.image)
+						try:
+							autodl.download(name, pdf=args.pdf, keep=args.keep, image=args.image)
+						except DownedSite:
+							print(f"can't access {name}, please retry it later")
 					elif not args.quiet:
-						print(f"can't access the xml for {name}, please retry it later")
+						print(f"can't access {name}, please retry it later")
+		except KeyboardInterrupt:
+			if not args.quiet:
+				print("\nmanual interruption")
 		finally:
 			autodl.save()
 			if not args.quiet:
